#include "flopc.hpp"
using namespace flopc;
#include "OsiClpSolverInterface.hpp"

int main() {
	MP_model &model	= MP_model::getDefaultModel();
	model.setSolver(new OsiClpSolverInterface);

	int i;
	MP_set A(5);                   // sets A = {0,...,4}
	MP_index a, b;
	MP_subset<1> B(A);
	B.insert(2); B.insert(3);      // sets B = {2, 3}
	B.display("set B");
	MP_data D(B);                  // data indexed on B
	for (i = 0; i < B.size(); i++)
		D(i) = 5*(i+1);              // sets D to 5 and 10
	D.display("data D");

	for (i = 0; i < A.size(); i++) // print indices of elements of A in B
		cout << "B(" << i << ") = " << B(i) << endl;

	MP_variable x(A);         // variable defined on set A

	MP_expression objF;       // linear expression (later used as objective)
	objF = sum(B, D(B) * x(B));
	objF = sum(B(A), D(B) * x(A));
	objF = sum(B(a), D(a) * x(a));
	objF = sum(B(a), D(B(a)) * x(a));
	objF = sum(B(a), D(B) * x(a));

	MP_constraint con(B);     // one constraint for each element of B
	con(B) = x(B) <= D(B);
	con(B(A)) = x(A) <= D(B);
	con(B(a)) = x(a) <= D(a);
	con(B(a)) = x(a) <= D(B(a));
	con(B(a)) = x(a) <= D(B);

	model.setObjective(objF);
	model.attach();
	model->writeMps("FlopCpp_set_example");

	return 0;
}
